@@ -12,13 +12,13 @@ Module::Starter - Starter kit for any module
 
 =head1 Version
 
-Version 1.20
+Version 1.22
 
-    $Header: /home/cvs/module-starter/Starter.pm,v 1.39 2004/07/12 03:29:05 andy Exp $
+    $Header: /home/cvs/module-starter/Starter.pm,v 1.41 2004/07/12 22:05:59 rjbs Exp $
 
 =cut
 
-our $VERSION = '1.20';
+our $VERSION = '1.22';
 
 =head1 Synopsis
 
@@ -205,19 +205,19 @@ package $module;
 use warnings;
 use strict;
 
-==head1 NAME
+\=head1 NAME
 
 $module - The great new $module!
 
-==head1 Version
+\=head1 Version
 
 Version 0.01
 
-==cut
+\=cut
 
 our \$VERSION = '0.01';
 
-==head1 Synopsis
+\=head1 Synopsis
 
 Quick summary of what the module does.
 
@@ -228,50 +228,50 @@ Perhaps a little code snippet.
     my \$foo = $module->new();
     ...
 
-==head1 Export
+\=head1 Export
 
 A list of functions that can be exported.  You can delete this section
 if you don't export anything, such as for a purely object-oriented module.
 
-==head1 Functions
+\=head1 Functions
 
-==head2 function1
+\=head2 function1
 
-==cut
+\=cut
 
 sub function1 {
 }
 
-=head2 function2
+\=head2 function2
 
-==cut
+\=cut
 
 sub function2 {
 }
 
-==head1 Author
+\=head1 Author
 
 $self->{author}, C<< <$self->{email}> >>
 
-==head1 Bugs
+\=head1 Bugs
 
 Please report any bugs or feature requests to
 C<bug-$rtname\@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.  I will be notified, and then you'll automatically
 be notified of progress on your bug as I make changes.
 
-==head1 Copyright & License
+\=head1 Copyright & License
 
 Copyright $year $self->{author}, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
-==cut
+\=cut
 
 1; # End of $module
 HERE
-    $content =~ s/^==/=/smg;
+    $content =~ s/^\\=/=/smg;
     return $content;
 }
 
